@@ -1,6 +1,6 @@
 import unittest
 
-from PyOfficeRobot.api.chat import chat_by_keyword
+from PyOfficeRobot.api.chat import *
 from PyOfficeRobot.api.file import *
 
 keywords = {
@@ -13,4 +13,7 @@ class TestFile(unittest.TestCase):
         send_file(who='文件传输助手', file=r'./test_files/0816.jpg')
 
     def test_chat_by_keyword(self):
-        chat_by_keyword(who='兆锋', keywords=keywords)
+        chat_by_keywords(who='兆锋', keywords=keywords)
+
+    def test_receive_message(self):
+        receive_message(who='程序员晚枫')
